This is an automated email from the ASF dual-hosted git repository.

lcwik pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git

commit 4479148a209a2b8226ab43cfae9ce2f413f08064
Author: Luke Cwik <lc...@google.com>
AuthorDate: Wed Apr 4 08:40:55 2018 -0700

    Replace Maven based Flink ValidatesRunner postcommit with Gradle based one.
---
 ...am_PostCommit_Java_ValidatesRunner_Flink.groovy | 25 +++++++---
 ...t_Java_ValidatesRunner_Flink_GradleBuild.groovy | 56 ----------------------
 2 files changed, 19 insertions(+), 62 deletions(-)

diff --git 
a/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink.groovy 
b/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink.groovy
index a0a957a..b9faeea6 100644
--- a/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink.groovy
+++ b/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink.groovy
@@ -19,15 +19,20 @@
 import common_job_properties
 
 // This job runs the suite of ValidatesRunner tests against the Flink runner.
-mavenJob('beam_PostCommit_Java_ValidatesRunner_Flink') {
+job('beam_PostCommit_Java_ValidatesRunner_Flink') {
   description('Runs the ValidatesRunner suite on the Flink runner.')
-  previousNames('beam_PostCommit_Java_RunnableOnService_Flink')
 
   // Set common parameters.
   common_job_properties.setTopLevelMainJobProperties(delegate)
 
-  // Set maven parameters.
-  common_job_properties.setMavenConfig(delegate)
+  def gradle_switches = [
+    // Gradle log verbosity enough to diagnose basic build issues
+    "--info",
+    // Continue the build even if there is a failure to show as many potential 
failures as possible.
+    '--continue',
+    // Until we verify the build cache is working appropriately, force 
rerunning all tasks
+    '--rerun-tasks',
+  ]
 
   // Sets that this is a PostCommit job.
   common_job_properties.setPostCommit(delegate)
@@ -38,6 +43,14 @@ mavenJob('beam_PostCommit_Java_ValidatesRunner_Flink') {
     'Apache Flink Runner ValidatesRunner Tests',
     'Run Flink ValidatesRunner')
 
-  // Maven goals for this job.
-  goals('-B -e clean verify -am -pl runners/flink 
-Plocal-validates-runner-tests')
+  // Gradle goals for this job.
+  steps {
+    gradle {
+      rootBuildScriptDir(common_job_properties.checkoutDir)
+      tasks(':runners:flink:validatesRunner')
+      for (String gradle_switch : gradle_switches) {
+        switches(gradle_switch)
+      }
+    }
+  }
 }
diff --git 
a/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink_GradleBuild.groovy
 
b/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink_GradleBuild.groovy
deleted file mode 100644
index b9bd941..0000000
--- 
a/.test-infra/jenkins/job_beam_PostCommit_Java_ValidatesRunner_Flink_GradleBuild.groovy
+++ /dev/null
@@ -1,56 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-import common_job_properties
-
-// This job runs the suite of ValidatesRunner tests against the Flink runner.
-job('beam_PostCommit_Java_ValidatesRunner_Flink') {
-  description('Runs the ValidatesRunner suite on the Flink runner.')
-
-  // Set common parameters.
-  common_job_properties.setTopLevelMainJobProperties(delegate)
-
-  def gradle_switches = [
-    // Gradle log verbosity enough to diagnose basic build issues
-    "--info",
-    // Continue the build even if there is a failure to show as many potential 
failures as possible.
-    '--continue',
-    // Until we verify the build cache is working appropriately, force 
rerunning all tasks
-    '--rerun-tasks',
-  ]
-
-  // Sets that this is a PostCommit job.
-  common_job_properties.setPostCommit(delegate)
-
-  // Allows triggering this build against pull requests.
-  common_job_properties.enablePhraseTriggeringFromPullRequest(
-    delegate,
-    'Apache Flink Runner ValidatesRunner Gradle Tests',
-    'Run Flink ValidatesRunner Gradle')
-
-  // Gradle goals for this job.
-  steps {
-    gradle {
-      rootBuildScriptDir(common_job_properties.checkoutDir)
-      tasks(':runners:flink:validatesRunner')
-      for (String gradle_switch : gradle_switches) {
-        switches(gradle_switch)
-      }
-    }
-  }
-}

-- 
To stop receiving notification emails like this one, please contact
lc...@apache.org.

Reply via email to